@@ -7,6 +7,7 @@ class ApplicationAgentCredential:
         if message is None:
             return None
 
+        fields = [desc.name for desc, val in message.ListFields()]
         application_agent_credential = ApplicationAgentCredential(
             str(message.id),
             str(message.kid),
@@ -17,15 +18,18 @@ class ApplicationAgentCredential:
             str(message.application_agent_id)
         )
 
-        if message.HasField('create_time'):
+        if "create_time" in fields:
             application_agent_credential.create_time = timestamp_to_date(message.create_time)
 
-        if message.HasField('destroy_time'):
+        if "destroy_time" in fields:
             application_agent_credential.destroy_time = timestamp_to_date(message.destroy_time)
 
-        if message.HasField('delete_time'):
+        if "delete_time" in fields:
             application_agent_credential.delete_time = timestamp_to_date(message.delete_time)
 
+        if "created_by" in fields:
+            application_agent_credential.created_by = str(message.created_by)
+
         return application_agent_credential
 
     def __init__(self, id, kid, display_name, customer_id, app_space_id, application_id, application_agent_id):
@@ -39,5 +43,6 @@ class ApplicationAgentCredential:
         self.create_time = None
         self.destroy_time = None
         self.delete_time = None
+        self.created_by = None
 
 
