@@ -13,16 +13,16 @@ class CreateApplicationSpace:
             timestamp_to_date(message.update_time),
             str(message.etag),
             str(message.bookmark),
+            str(message.created_by),
+            str(message.updated_by)
         )
-
         return create_application_space
 
-    def __init__(self, id, create_time, update_time, etag, bookmark):
+    def __init__(self, id, create_time, update_time, etag, bookmark, created_by, updated_by):
         self.id = id
         self.create_time = create_time
         self.update_time = update_time
         self.etag = etag
         self.bookmark = bookmark
-
-
-
+        self.created_by = created_by
+        self.updated_by = updated_by
