@@ -6,7 +6,7 @@ class Customer:
     def deserialize(cls, message):
         if message is None:
             return None
-
+        fields = [desc.name for desc, val in message.ListFields()]
         customer = Customer(
             str(message.id),
             str(message.name),
@@ -14,21 +14,27 @@ class Customer:
             str(message.etag)
         )
 
-        if message.HasField('create_time'):
+        if "create_time" in fields:
             customer.create_time = timestamp_to_date(message.create_time)
 
-        if message.HasField('update_time'):
+        if "update_time" in fields:
             customer.update_time = timestamp_to_date(message.update_time)
 
-        if message.HasField('destroy_time'):
+        if "destroy_time" in fields:
             customer.destroy_time = timestamp_to_date(message.destroy_time)
 
-        if message.HasField('delete_time'):
+        if "delete_time" in fields:
             customer.delete_time = timestamp_to_date(message.delete_time)
 
-        if message.HasField('description'):
+        if "description" in fields:
             customer.description = str(message.description)
 
+        if "created_by" in fields:
+            customer.created_by = str(message.created_by)
+
+        if "updated_by" in fields:
+            customer.updated_by = str(message.updated_by)
+
         return customer
 
     def __init__(self, id, name, display_name, etag):
@@ -41,5 +47,5 @@ class Customer:
         self.destroy_time = None
         self.delete_time = None
         self.description = None
-
-
+        self.created_by = None
+        self.updated_by = None
