@@ -27,19 +27,24 @@ class IsAuthorizedResponse:
 
 class IsAuthorizedResource:
 
-    def __init__(self, id: any, label):
-        self.id = id
-        self.label = label
+    def __init__(self, external_id: any, type, actions=[]):
+        self.external_id = external_id
+        self.type = type
+        self.actions = actions
 
 
-class IsAuthorizedDecisions:
-    def __init__(self, decision, allow_action):
-        self.decision = decision
-        self.allow_action = allow_action
+class IsAuthorizedResourceTypeResponse:
+
+    def __init__(self, resources={}):
+        self.resources = resources
 
 
-class IsAuthorizedActions:
-    def __init__(self, action, is_allowed):
-        self.action = action
-        self.is_allowed = is_allowed
+class IsAuthorizedResourceResponse:
 
+    def __init__(self, actions={}):
+        self.actions = actions
+
+
+class IsAuthorizedActionResponse:
+    def __init__(self, allow=False):
+        self.allow = allow
